Module pros::error

source ·
Helpers for dealing with errno.

Most errors in pros-rs are created by reading the last value of ERRNO. This includes the very generic PortError, which is used for most hardware that gets plugged into a port on a V5 Brain.

Most of the contents of this file are not public.

Enums

Traits